pub enum ModelDType {
Auto,
BF16,
F16,
F32,
}Expand description
DType for the model.
If the model is quantized, this is ignored so it is reasonable to use the Default impl.
Note: When using Auto, fallback pattern is: BF16 -> F16 -> 32
Variants