pub fn get_engine_terminate_flag() -> Arc<AtomicBool> ⓘExpand description
Get or create a termination flag for the current engine thread.
pub fn get_engine_terminate_flag() -> Arc<AtomicBool> ⓘGet or create a termination flag for the current engine thread.