pub fn initialize_logging()Expand description
This should be called to initialize the debug flag and logging. This should not be called in hanzo-engine code due to Rust usage.
pub fn initialize_logging()This should be called to initialize the debug flag and logging. This should not be called in hanzo-engine code due to Rust usage.