pub type ToolCallback = dyn Fn(&CalledFunction, &ToolCallContext) -> Result<String, Error> + Sync + Send;Expand description
Custom tool callback. Receives the called function and returns the tool output as a string.
pub type ToolCallback = dyn Fn(&CalledFunction, &ToolCallContext) -> Result<String, Error> + Sync + Send;Custom tool callback. Receives the called function and returns the tool output as a string.