pub trait MultimodalPromptPrefixer: Send + Sync {
// Provided methods
fn prefix_image(&self, _image_indices: Vec<usize>, prompt: &str) -> String { ... }
fn prefix_audio(&self, _audio_indexes: Vec<usize>, prompt: &str) -> String { ... }
fn prefix_video(&self, _video_indexes: Vec<usize>, prompt: &str) -> String { ... }
}Expand description
Prepend a vision tag appropriate for the model to the prompt. Image indexing is assumed that start at 0.
Provided Methods
Sourcefn prefix_image(&self, _image_indices: Vec<usize>, prompt: &str) -> String
fn prefix_image(&self, _image_indices: Vec<usize>, prompt: &str) -> String
Prefix for inclusion in messages (may do nothing if the chat template handles it).
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".