pub type ToolCallback = dyn Fn(&CalledFunction, &ToolCallContext) -> Result<String, Error> + Send + Sync;Expand description
Custom tool callback. Receives the called function and returns the tool output as a string.
pub type ToolCallback = dyn Fn(&CalledFunction, &ToolCallContext) -> Result<String, Error> + Send + Sync;Custom tool callback. Receives the called function and returns the tool output as a string.